@@ -24,10 +24,11 @@
  *
  * ============================================================ */
 
-#include "mainwindow.moc"
+#include "mainwindow.h"
 
 // Qt includes
 
+#include <QAction>
 #include <QStandardItemModel>
 #include <QCloseEvent>
 #include <QComboBox>
@@ -41,33 +42,32 @@
 #include <QTimer>
 #include <QTreeWidget>
 #include <QVBoxLayout>
-#include <qtconcurrentmap.h>
+#include <QtConcurrentMap>
+#include <QCommandLineParser>
+#include <QMenuBar>
+#include <QFileDialog>
+#include <QStatusBar>
+#include <QPointer>
+#include <QProgressBar>
+#include <QDebug>
 
 // KDE includes
 
-#include <kaction.h>
-#include <kcmdlineargs.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
-#include <kfiledialog.h>
-#include <kiconloader.h>
-#include <klineedit.h>
-#include <klocale.h>
-#include <kmenu.h>
-#include <kmenubar.h>
-#include <kstatusbar.h>
+#include <klocalizedstring.h>
 
 // LibKExiv2 includes
 
-#include <libkexiv2/version.h>
-#include <libkexiv2/kexiv2.h>
+#include <kexiv2.h>
 
 // libkgeomap includes
 
-#include "libkgeomap/lookup_altitude.h"
-#include "libkgeomap/lookup_factory.h"
-#include "libkgeomap/kgeomap_widget.h"
-#include "libkgeomap/itemmarkertiler.h"
+#include "src/lookupaltitude.h"
+#include "src/lookupfactory.h"
+#include "src/mapwidget.h"
+#include "src/itemmarkertiler.h"
+#include "src/kgeomap_common.h"
 
 // local includes
 
@@ -130,7 +130,7 @@ class MyImageData
 public:
 
     GeoCoordinates coordinates;
-    KUrl           url;
+    QUrl           url;
 };
 
 // ----------------------------------------------------------------------
@@ -206,7 +206,7 @@ public:
     }
 
     QSplitter*                          splitter;
-    KGeoMapWidget*                      mapWidget;
+    MapWidget*                      mapWidget;
     QList<LookupAltitude*>              lookupAltitudeList;
     MyTreeWidget*                       treeWidget;
     QPointer<QProgressBar>              progressBar;
@@ -216,8 +216,8 @@ public:
     int                                 imageLoadingCurrentCount;
     QList<MyImageData>                  imageLoadingBuncher;
     QTimer*                             imageLoadingBunchTimer;
-    KCmdLineArgs*                       cmdLineArgs;
-    KUrl                                lastImageOpenDir;
+    QCommandLineParser*                 cmdLineArgs;
+    QUrl                                lastImageOpenDir;
 
     QAbstractItemModel*                 displayMarkersModel;
     QItemSelectionModel*                selectionModel;
@@ -225,8 +225,9 @@ public:
     MyTrackModelHelper*                 trackModelHelper;
 };
 
-MainWindow::MainWindow(KCmdLineArgs* const cmdLineArgs, QWidget* const parent)
-    : KMainWindow(parent), d(new Private())
+MainWindow::MainWindow(QCommandLineParser* const cmdLineArgs, QWidget* const parent)
+    : QMainWindow(parent),
+      d(new Private())
 {
     // initialize kexiv2 before doing any multitasking
     KExiv2Iface::KExiv2::initializeExiv2();
@@ -244,7 +245,7 @@ MainWindow::MainWindow(KCmdLineArgs* const cmdLineArgs, QWidget* const parent)
 
     resize(512, 512);
     setWindowTitle(i18n("LibKGeoMap demo"));
-    setWindowIcon(SmallIcon( QLatin1String("applications-internet" )));
+    setWindowIcon(QIcon::fromTheme(QString::fromLatin1("applications-internet")));
     setObjectName(QLatin1String("Demo-KGeoMap" ));
 
     d->cmdLineArgs = cmdLineArgs;
@@ -262,7 +263,7 @@ MainWindow::MainWindow(KCmdLineArgs* const cmdLineArgs, QWidget* const parent)
     d->splitter = new QSplitter(Qt::Vertical, this);
     setCentralWidget(d->splitter);
 
-    d->mapWidget = new KGeoMapWidget(d->splitter);
+    d->mapWidget = new MapWidget(d->splitter);
     d->mapWidget->setGroupedModel(mm);
     d->mapWidget->setActive(true);
     d->mapWidget->setDragDropHandler(new DemoDragDropHandler(d->displayMarkersModel, d->mapWidget));
@@ -312,7 +313,7 @@ MainWindow::MainWindow(KCmdLineArgs* const cmdLineArgs, QWidget* const parent)
     // Sagrada Familia in Spain
     markerList<<GeoCoordinates::fromGeoUrl(QLatin1String("geo:41.4036480511,2.1743756533,46" ));
 
-    if (cmdLineArgs->isSet("demopoints_single") || cmdLineArgs->isSet("demopoints_group"))
+    if (cmdLineArgs->isSet(QString::fromLatin1("demopoints_single")) || cmdLineArgs->isSet(QString::fromLatin1("demopoints_group")))
     {
         for (int i = 0; i < markerList.count(); ++i)
         {
@@ -346,7 +347,7 @@ void MainWindow::readSettings()
     d->mapWidget->readSettingsFromGroup(&groupWidgetConfig);
 
     KConfigGroup groupMainWindowConfig = config.group(QLatin1String("MainWindowConfig"));
-    d->lastImageOpenDir                = groupMainWindowConfig.readEntry("Last Image Open Directory", KUrl());
+    d->lastImageOpenDir                = groupMainWindowConfig.readEntry("Last Image Open Directory", QUrl());
 
     if (groupMainWindowConfig.hasKey("SplitterState"))
     {
@@ -367,7 +368,7 @@ void MainWindow::saveSettings()
     d->mapWidget->saveSettingsToGroup(&groupWidgetConfig);
 
     KConfigGroup groupMainWindowConfig = config.group(QLatin1String("MainWindowConfig"));
-    groupMainWindowConfig.writeEntry("Last Image Open Directory", d->lastImageOpenDir);
+    groupMainWindowConfig.writeEntry("Last Image Open Directory", d->lastImageOpenDir.toLocalFile());
     groupMainWindowConfig.writeEntry(QLatin1String("SplitterState"), d->splitter->saveState().toBase64());
 }
 
@@ -380,7 +381,7 @@ void MainWindow::closeEvent(QCloseEvent* e)
     e->accept();
 }
 
-MyImageData LoadImageData(const KUrl& urlToLoad)
+MyImageData LoadImageData(const QUrl& urlToLoad)
 {
     MyImageData imageData;
     imageData.url = urlToLoad;
@@ -401,7 +402,7 @@ MyImageData LoadImageData(const KUrl& urlToLoad)
 
 void MainWindow::slotFutureResultsReadyAt(int startIndex, int endIndex)
 {
-//     kDebug()<<"future"<<startIndex<<endIndex;
+//     //qDebug()<<"future"<<startIndex<<endIndex;
 
     // determine the sender:
     QFutureWatcher<MyImageData>* const futureSender = reinterpret_cast<QFutureWatcher<MyImageData>*>(sender());
@@ -432,7 +433,7 @@ void MainWindow::slotFutureResultsReadyAt(int startIndex, int endIndex)
     for (int index = startIndex; index < endIndex; ++index)
     {
         MyImageData newData = d->imageLoadingRunningFutures.at(futureIndex).resultAt(index);
-//         kDebug()<<"future"<<newData.url<<newData.coordinates.geoUrl();
+//         //qDebug()<<"future"<<newData.url<<newData.coordinates.geoUrl();
 
         d->imageLoadingBuncher << newData;
     }
@@ -462,7 +463,7 @@ void MainWindow::slotFutureResultsReadyAt(int startIndex, int endIndex)
     }
 }
 
-void MainWindow::slotScheduleImagesForLoading(const KUrl::List imagesToSchedule)
+void MainWindow::slotScheduleImagesForLoading(const QList<QUrl> imagesToSchedule)
 {
     if (imagesToSchedule.isEmpty())
         return;
@@ -490,7 +491,7 @@ void MainWindow::slotScheduleImagesForLoading(const KUrl::List imagesToSchedule)
 
 void MainWindow::slotImageLoadingBunchReady()
 {
-    kDebug()<<"slotImageLoadingBunchReady";
+    qDebug()<<"slotImageLoadingBunchReady";
 
     for (int i = 0; i < d->imageLoadingBuncher.count(); ++i)
     {
@@ -530,7 +531,7 @@ void MainWindow::slotMarkersMoved(const QList<QPersistentModelIndex>& markerIndi
 
     if (!altitudeQueries.isEmpty())
     {
-        LookupAltitude* const myAltitudeLookup = LookupFactory::getAltitudeLookup("geonames", this);
+        LookupAltitude* const myAltitudeLookup = LookupFactory::getAltitudeLookup(QString::fromLatin1("geonames"), this);
 
         connect(myAltitudeLookup, SIGNAL(signalRequestsReady(QList<int>)),
                 this, SLOT(slotAltitudeRequestsReady(QList<int>)));
@@ -544,13 +545,13 @@ void MainWindow::slotMarkersMoved(const QList<QPersistentModelIndex>& markerIndi
 
         /// @todo Check the return value?
         myAltitudeLookup->startLookup();
-        kDebug()<<"Starting lookup for "<<altitudeQueries.count()<<" items!";
+        qDebug() << "Starting lookup for " << altitudeQueries.count() << " items!";
     }
 }
 
 void MainWindow::slotAltitudeRequestsReady(const QList<int>& readyRequests)
 {
-    kDebug()<<readyRequests.count() << " items ready!";
+    qDebug() << readyRequests.count() << " items ready!";
     LookupAltitude* const myAltitudeLookup = qobject_cast<LookupAltitude*>(sender());
 
     if (!myAltitudeLookup)
@@ -589,12 +590,12 @@ void MainWindow::slotAltitudeLookupDone()
 
 void MainWindow::slotAddImages()
 {
-    const KUrl::List fileNames = KFileDialog::getOpenUrls(d->lastImageOpenDir, QLatin1String("*.jpg|*.jpeg|*.png"), this, i18n("Add image files"));
+    const QList<QUrl> fileNames = QFileDialog::getOpenFileUrls(this, i18n("Add image files"), d->lastImageOpenDir, i18n("Images (*.jpg *.jpeg *.png *.tif *.tiff)"));
 
     if (fileNames.isEmpty())
         return;
 
-    d->lastImageOpenDir        = fileNames.first().upUrl();
+    d->lastImageOpenDir        = fileNames.first().resolved(QUrl(QString::fromLatin1("../")));
 
     slotScheduleImagesForLoading(fileNames);
 }
@@ -602,13 +603,11 @@ void MainWindow::slotAddImages()
 void MainWindow::createMenus()
 {
     QMenu* const fileMenu         = menuBar()->addMenu(i18n("File"));
-    KAction* const addFilesAction = new KAction(i18n("Add images..."), fileMenu);
+    QAction* const addFilesAction = new QAction(i18n("Add images..."), fileMenu);
     fileMenu->addAction(addFilesAction);
 
     connect(addFilesAction, SIGNAL(triggered()),
             this, SLOT(slotAddImages()));
-
-    menuBar()->addMenu(helpMenu());
 }
 
 KGeoMap::ModelHelper::Flags MarkerModelHelper::modelFlags() const
